@@ -40,14 +40,7 @@ static void applyDriverName(VkPhysicalDeviceDriverPropertiesKHR* properties, FFs
 static const char* detectVulkan(FFVulkanResult* result)
 {
     FF_LIBRARY_LOAD(vulkan, "dlopen libvulkan" FF_LIBRARY_EXTENSION " failed",
-        #if __ANDROID__
-            #if UINTPTR_MAX == UINT32_MAX
-                "/system/lib/"
-            #else
-                "/system/lib64/"
-            #endif
-            "libvulkan" FF_LIBRARY_EXTENSION, -1
-        #elif __APPLE__
+        #if __APPLE__
             "libMoltenVK" FF_LIBRARY_EXTENSION, -1
         #elif _WIN32
             "vulkan-1" FF_LIBRARY_EXTENSION, -1
@@ -225,7 +218,7 @@ static const char* detectVulkan(FFVulkanResult* result)
         ffStrbufInitS(&gpu->name, physicalDeviceProperties.properties.deviceName);
 
         gpu->type = physicalDeviceProperties.properties.deviceType == VK_PHYSICAL_DEVICE_TYPE_DISCRETE_GPU ? FF_GPU_TYPE_DISCRETE : FF_GPU_TYPE_INTEGRATED;
-        ffStrbufInitS(&gpu->vendor, ffGetGPUVendorString(physicalDeviceProperties.properties.vendorID));
+        ffStrbufInitS(&gpu->vendor, ffGPUGetVendorString(physicalDeviceProperties.properties.vendorID));
         ffStrbufInitS(&gpu->driver, driverProperties.driverInfo);
 
         VkPhysicalDeviceMemoryProperties memoryProperties = {};
